@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996, 1997, 2000, 2005, 2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -32,6 +31,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "sysdir.h"
 
 #include "dir-ops.h"
+#include "file-ops.h"
 #include "lo-error.h"
 #include "lo-sysdep.h"
 #include "str-vec.h"
@@ -47,8 +47,10 @@ dir_entry::open (const std::string& n)
   if (! name.empty ())
     {
       close ();
+      
+      std::string fullname = file_ops::tilde_expand (name);
 
-      dir = static_cast<void *> (opendir (name.c_str ()));
+      dir = static_cast<void *> (opendir (fullname.c_str ()));
 
       if (dir)
 	fail = false;
@@ -67,6 +69,10 @@ dir_entry::open (const std::string& n)
 string_vector
 dir_entry::read (void)
 {
+  static octave_idx_type grow_size = 100;
+
+  octave_idx_type len = 0;
+
   string_vector dirlist;
 
   if (ok ())
@@ -76,21 +82,24 @@ dir_entry::read (void)
       struct dirent *dir_ent;
 
       while ((dir_ent = readdir (static_cast<DIR *> (dir))))
-	count++;
-
-      rewinddir (static_cast<DIR *> (dir));
-
-      dirlist.resize (count);
-
-      for (int i = 0; i < count; i++)
 	{
-	  dir_ent = readdir (static_cast<DIR *> (dir));
-
 	  if (dir_ent)
-	    dirlist[i] = dir_ent->d_name;
+	    {
+	      if (count >= len)
+		{
+		  len += grow_size;
+		  dirlist.resize (len);
+		}
+
+	      dirlist[count] = dir_ent->d_name;
+
+	      count++;
+	    }
 	  else
 	    break;
 	}
+
+      dirlist.resize (count);
     }
 
   return dirlist;
