@@ -53,28 +53,28 @@
 
 function sys = starp (P, K, ny, nu);
 
-  if((nargin != 2) && (nargin != 4))
+  if (nargin != 2 && nargin != 4)
     print_usage ();
   endif
-  if (!isstruct(P))
-    error("---> P must be in system data structure");
+  if (! isstruct (P))
+    error ("---> P must be in system data structure");
   endif
-  if (!isstruct(K))
-    error("---> K must be in system data structure");
+  if (! isstruct (K))
+    error ("---> K must be in system data structure");
   endif
 
-  P = sysupdate(P, "ss");
-  [n, nz, mp, pp] = sysdimensions(P);
+  P = sysupdate (P, "ss");
+  [n, nz, mp, pp] = sysdimensions (P);
   np = n + nz;
-  K = sysupdate(K, "ss");
-  [n, nz, mk, pk] = sysdimensions(K);
+  K = sysupdate (K, "ss");
+  [n, nz, mk, pk] = sysdimensions (K);
   nk = n + nz;
   ny_sign = 1;
   nu_sign = 1;
   if (nargin == 2)
     ## perform a LFT of P and K (upper or lower)
-    ny = min([pp, mk]);
-    nu = min([pk, mp]);
+    ny = min ([pp, mk]);
+    nu = min ([pk, mp]);
   else
     if (ny < 0)
       ny = -ny;
@@ -86,40 +86,48 @@ function sys = starp (P, K, ny, nu);
     endif
   endif
   if (ny > pp)
-    error("---> P has not enough outputs.");
+    error ("---> P has not enough outputs.");
   endif
   if (nu > mp)
-    error("---> P has not enough inputs.");
+    error ("---> P has not enough inputs.");
   endif
   if (ny > mk)
-    error("---> K has not enough inputs.");
+    error ("---> K has not enough inputs.");
   endif
   if (nu > pk)
-    error("---> K has not enough outputs.");
+    error ("---> K has not enough outputs.");
   endif
   nwp  = mp - nu;
   nzp  = pp - ny;
   nwk  = mk - ny;
   nzk  = pk - nu;
-  if ((nwp + nwk) < 1)
-    error("---> no inputs left for star product.");
+  if (nwp + nwk < 1)
+    error ("---> no inputs left for star product.");
   endif
-  if ((nzp + nzk) < 1)
-    error("---> no outputs left for star product.");
+  if (nzp + nzk < 1)
+    error ("---> no outputs left for star product.");
   endif
 
   ## checks done, form sys
-  if (nzp)  Olst = [1:nzp];  endif
-  if (nzk)  Olst = [Olst, pp+nu+1:pp+pk];  endif
-  if (nwp)  Ilst = [1:nwp];  endif
-  if (nwk)  Ilst = [Ilst, mp+ny+1:mp+mk];  endif
-  Clst = zeros(ny+nu,2);
+  if (nzp)
+    Olst = 1:nzp;
+  endif
+  if (nzk)
+    Olst = [Olst, pp+nu+1:pp+pk];
+  endif
+  if (nwp)
+    Ilst = 1:nwp;
+  endif
+  if (nwk)
+    Ilst = [Ilst, mp+ny+1:mp+mk];
+  endif
+  Clst = zeros (ny+nu, 2);
   for ii = 1:nu
     Clst(ii,:) = [nwp+ii, nu_sign*(pp+ii)];
   endfor
   for ii = 1:ny
     Clst(nu+ii,:) = [mp+ii, ny_sign*(nzp+ii)];
   endfor
-  sys = buildssic(Clst,[],Olst,Ilst,P,K);
+  sys = buildssic (Clst, [], Olst, Ilst, P, K);
 
 endfunction
