@@ -29,7 +29,6 @@
 ## Without any arguments, @code{axis} turns autoscaling on.  
 ##
 ## With one output argument, @code{x=axis} returns the current axes 
-## (this is not yet implemented for automatic axes).
 ##
 ## The vector argument specifying limits is optional, and additional
 ## string arguments may be used to specify various axis properties.  For
@@ -109,17 +108,36 @@
 ## Restore y-axis, so higher values are nearer the top. 
 ## @end table
 ## 
+## If an axes handle is passed as the first argument, then operate on
+## this axes rather than the current axes.
 ## @end deftypefn
 
 ## Author: jwe
 
 ## PKG_ADD: mark_as_command axis
 
-function curr_axis = axis (ax, varargin)
+function varargout = axis (varargin)
 
-  ca = gca ();
+  [h, varargin, nargin] = __plt_get_axis_arg__ ("axis", varargin{:});
 
-  if (nargin == 0)
+  oldh = gca ();
+  unwind_protect
+    axes (h);
+    varargout = cell (max (nargin == 0, nargout), 1);
+    if (isempty (varargout))
+      __axis__ (h, varargin{:});
+    else
+      [varargout{:}] = __axis__ (h, varargin{:});
+    endif
+  unwind_protect_cleanup
+    axes (oldh);
+  end_unwind_protect
+
+endfunction
+
+function curr_axis = __axis__ (ca, ax, varargin)
+
+  if (nargin == 1)
     if (nargout == 0)
       set (ca, "xlimmode", "auto", "ylimmode", "auto", "zlimmode", "auto");
     else
@@ -254,8 +272,8 @@ function curr_axis = axis (ax, varargin)
     error ("axis: expecting no args, or a vector with 2, 4, or 6 elements");
   endif
 
-  if (nargin > 1)
-    axis (varargin{:});
+  if (nargin > 2)
+    __axis__ (ca, varargin{:});
   endif
 
 endfunction
