@@ -1,19 +1,21 @@
-## Copyright (C) 1998-2004 Andy Adler
+## Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+##               2007 Andy Adler
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## This file is part of Octave.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## Octave is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
+##
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301  USA
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} spy (@var{x})
@@ -28,6 +30,10 @@
 
 function spy (S, varargin) 
 
+  if (nargin < 1)
+    print_usage ();
+  endif
+
   markersize = NaN;
   if (numel (i) < 1000)
     LineSpec = "*";
@@ -57,6 +63,6 @@ function spy (S, varargin)
     plot (j, i, LineSpec, "MarkerSize", markersize);
   endif
 
-  axis ([0, n+1, m+1, 0]);
+  axis ([0, n+1, 0, m+1], "ij");
 
 endfunction
