@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1999 John W. Eaton
+Copyright (C) 1999, 2000, 2002, 2003, 2004, 2005, 2006, 2007
+              John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -63,11 +63,11 @@ public:
 
   void assign (const octave_value_list& idx, const octave_value& rhs);
 
-  octave_value *clone (void) const { return new octave_cell (*this); }
-  octave_value *empty_clone (void) const { return new octave_cell (); }
+  octave_base_value *clone (void) const { return new octave_cell (*this); }
+  octave_base_value *empty_clone (void) const { return new octave_cell (); }
 
 #if 0
-  octave_value *try_narrowing_conversion (void);
+  octave_base_value *try_narrowing_conversion (void);
 #endif
 
   octave_value subsref (const std::string&,
@@ -97,14 +97,16 @@ public:
 
   bool is_cell (void) const { return true; }
 
+  bool is_cellstr (void) const { return matrix.is_cellstr (); }
+
   Cell cell_value (void) const { return matrix; }
 
   octave_value_list list_value (void) const;
 
-  octave_value convert_to_str_internal (bool pad, bool force, char type) const
-    { return octave_value (all_strings (pad, force), type); }
+  octave_value convert_to_str_internal (bool pad, bool, char type) const
+    { return octave_value (all_strings (pad), type); }
 
-  string_vector all_strings (bool pad = false, bool force = false) const;
+  string_vector all_strings (bool pad = false) const;
 
   bool print_as_scalar (void) const;
 
@@ -113,8 +115,7 @@ public:
   void print_raw (std::ostream& os, bool pr_as_read_syntax = false) const;
 
 
-  bool save_ascii (std::ostream& os, bool& infnan_warned,
-		 bool strip_nan_and_inf);
+  bool save_ascii (std::ostream& os);
 
   bool load_ascii (std::istream& is);
 
@@ -129,6 +130,8 @@ public:
   bool load_hdf5 (hid_t loc_id, const char *name, bool have_h5giterate_bug);
 #endif
 
+  mxArray *as_mxArray (void) const;
+
 private:
 
   DECLARE_OCTAVE_ALLOCATOR
